'**********************************************************************************
' Script Name: Disable_WebDAV_Remotely.vbs
'     Version: 1.0.1
'      Author: Jason Fossen, SANS Institute (www.sans.org)
'Last Updated: 3/20/03
'     Purpose: Scans a range of IP addresses, connects to each Windows 2000/XP/2003
'              system on which you have administrative access, sets the registry
'              value to disable WebDAV and restarts the WWW service.
'       Usage: Takes two arguments: beginning IP address and ending IP address.
'              Run in a CMD window.  Use CSCRIPT.EXE instead of WSCRIPT.EXE.  Use
'              the same IP address twice to affect only that one system.
'       Notes: If you have WSH 5.6 or later, then alter the script below so that
'              only machines which respond to pings will be attempted.  Otherwise,
'              the script will attempt to connect to non-existent machines for
'              up to 40 seconds each (a bit slow for scanning...).  Get WSH 5.6
'              or later from http://msdn.microsoft.com/scripting/  (it's free).
'       Legal: Public Domain.  Modify and redistribute freely.  No rights reserved.
'              Script provided "as is" without implied warranty or guarantee.  Use
'              at your own risk and only on networks with prior written permission.
'              No technical support is provided.
'**********************************************************************************

On Error Resume Next
Dim iStart, iEnd, sAddress, sIP, oWshShell
Set oWshShell = CreateObject("WScript.Shell")

If WScript.Arguments.Count <> 2 Then
    WScript.Echo vbCrLf & "Script requires two arguments: beginning-IP ending-IP."
    WScript.Echo "For example: cscript.exe Disable_WebDAV_Remotely.vbs 10.4.1.1 10.4.1.254"
    WScript.Echo "The script will disable WebDAV at each machine and attempt to restart the"
    WScript.Echo "World Wide Web Publishing service.  Redirect the script's output to a file"
    WScript.Echo "to keep a log of its successes and failures.  You must have administrative"
    WScript.Echo "rights on the target machine for the script to work.  It will work against"
    WScript.Echo "target machines that support Windows Management Instrumentation (WMI)"
    WScript.Echo "only, so this means only Windows 2000/XP/2003 by default.  If you are "
    WScript.Echo "running the script from a system with WSH 5.6 or later, you may wish to"
    WScript.Echo "uncomment the lines in the script (53 and 68) which perform a ping test"
    WScript.Echo "of the target before attempting to disable WebDAV (much more efficient)."
    WScript.Echo "To disable WebDAV at one system only, pass in its IP address twice."
    WScript.Quit
Else
    iStart = IP2Number(WScript.Arguments.Item(0))
    iEnd   = IP2Number(WScript.Arguments.Item(1))
End If


For sAddress = iStart To iEnd
	sIP = Number2IP(sAddress)
	WScript.Echo vbCrLf & "Attempting to connect to " & sIP & " ..." & vbCrLf
   'If IsPingable(sIP) Then   'This requires WSH 5.6 or later.
        If SetRegistryValue(sIP,"HKLM","SYSTEM\CurrentControlSet\Services\W3SVC\Parameters","DisableWebDAV","REG_DWORD",1) Then  
            WScript.Echo "Registry successfully changed to disable WebDAV at " & sIP
            If StopServiceAndAntecedents(sIP,"W3SVC") Then 
                WScript.Echo "Successfully stopped WWW service at " & sIP
                If StartServiceAndAutostartDependents(sIP,"W3SVC") Then
                    WScript.Echo "Successfully restarted WWW service at " & sIP
                Else
                    WScript.Echo "Failed to restart WWW service or a service that depends on it at " & sIP & ". Check that machine."
                End If
            Else
                WScript.Echo "Failed to stop WWW service or its dependent services at " & sIP & ".  Check that machine."
                StartServiceAndAutostartDependents sIP,"W3SVC"  'No point in leaving it half-disabled...
            End If
        End If
    'End If     'This is for the IsPingable(sIP) test.  Requires WSH 5.6 or later.    
Next




'***********************************************************************************
'        Name: SetRegistryValue()
'     Purpose: Connects to local/remote system on which you have administrative 
'              rights and sets/creates any registry value.  Function returns True
'              if no problems, false otherwise.
'       Notes: Script does not create any registry keys, but it will create the
'              specified value if it does not exist.  Use the period (".") to denote
'              the local machine.  When creating REG_MULTI_SZ or REG_BINARY values, 
'              the input value must be an array of strings or bytes, respectively.
'              Target machine must support WMI, e.g., Windows 2000/XP/2003.
'              If you will be setting many values on one machine, modify the code
'              to pass in an array of values and set them all with one
'              WMI connection (which uses an authenticated RPC channel).
'***********************************************************************************

Function SetRegistryValue(sIPaddress,sHive,sPath,sValueName,sValueType,sValue)
    On Error Resume Next
    
    Const HKEY_LOCAL_MACHINE  = &H80000002
    Const HKEY_CLASSES_ROOT   = &H80000000
    Const HKEY_CURRENT_USER   = &H80000001 
    Const HKEY_USERS          = &H80000003
    Const HKEY_CURRENT_CONFIG = &H80000005 
    Const HKEY_DYN_DATA       = &H80000006  'Valid on Windows 9x only.
    
    Const REG_SZ              = 1
    Const REG_EXPAND_SZ       = 2
    Const REG_BINARY          = 3
    Const REG_DWORD           = 4
    Const REG_MULTI_SZ        = 7
    
    Dim oRegistry, bReturn
    
    If InStr(sPath,"\") = 1 Then sPath = Trim(Right(sPath,Len(sPath) - 1))    'sPath should not start with a backslash.
    sHive = Trim(UCase(Replace(sHive,"\","")))         'sHive should have no backslashes and be in uppercase.
    sValueName = Trim(Replace(sValueName,"\",""))      'sValueName should have no backslashes.
    sValueType = Trim(UCase(sValueType))   
    
    Set oRegistry = GetObject("WinMgmts:{ImpersonationLevel=Impersonate}!\\" & _ 
                                sIPaddress & "\root\default:StdRegProv")
    
    If Err.Number <> 0 Then
        'WScript.Echo Err.Description & ": " & sIPaddress
        SetRegistryValue = False
        Exit Function
    End If
    
    Select Case sHive
        Case "HKEY_LOCAL_MACHINE","HKLM" 
            sHive = HKEY_LOCAL_MACHINE
        Case "HKEY_CLASSES_ROOT","HKCR"
            sHive = HKEY_CLASSES_ROOT
        Case "HKEY_CURRENT_USER","HKCU"
            sHive = HKEY_CURRENT_USER
        Case "HKEY_USERS","HKU"
            sHive = HKEY_USERS
        Case "HKEY_CURRENT_CONFIG","HKCC"
            sHive = HKEY_CURRENT_CONFIG
        Case "HKEY_DYN_DATA","HKDD"
            sHive = HKEY_DYN_DATA
        Case Else
            SetRegistryValue = False
            Exit Function
    End Select
    
    Select Case sValueType
        Case "REG_DWORD","DWORD"
            bReturn = oRegistry.SetDWORDValue(sHive,sPath,sValueName,sValue)
            
        Case "REG_SZ","SZ"
            bReturn = oRegistry.SetStringValue(sHive,sPath,sValueName,CStr(sValue))
            
        Case "REG_EXPAND_SZ","EXPAND_SZ","EXPAND"
            bReturn = oRegistry.SetExpandedStringValue(sHive,sPath,sValueName,CStr(sValue))
            
        Case "REG_MULTI_SZ","MULTI_SZ","MULTI"
            If VarType(sValue) >= vbArray Then  'MULTI_SZ requires an array of strings.
                bReturn = oRegistry.SetMultiStringValue(sHive,sPath,sValueName,sValue)
            Else
                SetRegistryValue = False
                Exit Function
            End If
            
        Case "REG_BINARY","BINARY"
            If VarType(sValue) >= vbArray Then  'REG_BINARY requires an array of bytes.
                bReturn = oRegistry.SetBinaryValue(sHive,sPath,sValueName,sValue)
            Else
                SetRegistryValue = False
                Exit Function
            End If
            
        Case Else
            SetRegistryValue = False
            Exit Function
    End Select
    
    If (Err.Number = 0) And (bReturn = 0) Then 
        SetRegistryValue = True 
    Else 
        SetRegistryValue = False
    End If
    
    Set oRegistry = Nothing
End Function





'**********************************************************************************
' Function: IP2Number()
' Purpose: Convert a valid doted decimal IP address to
'          a 32-bit number.
'**********************************************************************************
Function IP2Number(ByVal sIP)
	aOctets = Split(sIP,".")
	IP2Number = (Int(aOctets(0)) * 16777216) + _
	            (Int(aOctets(1)) * 65536   ) + _ 
	            (Int(aOctets(2)) * 256     ) + _
	            (Int(aOctets(3))           )      
End Function




'**********************************************************************************
' Function: Number2IP()
' Purpose: Convert a 32-bit number to an IP address.
'**********************************************************************************
Function Number2IP(ByVal iNumber)
	Dim aOctets(4)
	aOctets(0) = Int(iNumber / 16777216)
    	iNumber = iNumber - (aOctets(0) * 16777216)
	aOctets(1) = Int(iNumber / 65536)
    	iNumber = iNumber - (aOctets(1) * 65536)   
	aOctets(2) = Int(iNumber / 256)
	aOctets(3) = iNumber - (aOctets(2) * 256)
	Number2IP = CStr(aOctets(0) & "." & aOctets(1) & "." & aOctets(2) & "." & aOctets(3))
End Function





'***********************************************************************************
'    Function: IsPingable()
'     Purpose: Captures the standard out (StdOut) of a launched process and uses
'              it to test whether a target IP address is pingable.
'       Notes: Requires WSH 5.6 or later!  
'       Notes: Modify the -n and -w switches in the Ping command to meet your needs.
'***********************************************************************************
Function IsPingable(sIPaddress)
    On Error Resume Next
	Dim sCommand, oExec, sLine
	sCommand = "ping.exe -n 2 -w 3000 " & sIPaddress  	
	IsPingable = False 
	
	If Not IsObject(oWshShell) Then Set oWshShell = CreateObject("WScript.Shell")
	Set oExec = oWshShell.Exec(sCommand)
		
	Do While Not oExec.StdOut.AtEndOfStream
		sLine = oExec.StdOut.ReadLine
	    If InStr(sLine,"Reply") <> 0 Then 
	    	IsPingable = True
	    	Exit Do
	    End If
	Loop
	
	Set oExec = Nothing
End Function




'**********************************************************************************
'  Function: StopServiceAndAntecedents()
'   Purpose: Will stop a service on a remote machine, including any services
'            that depend on it, i.e., "antecedent services" in WMI-speak.
'**********************************************************************************
Function StopServiceAndAntecedents(sIPaddress,sServiceName)
    On Error Resume Next
    Dim oWMI, cTargetService, cServicesThatDependOnIt, bFlag
    bFlag = True  'Assume function will work until error is detected.
    
    Set oWMI = GetObject("WinMgmts:{ImpersonationLevel=Impersonate}!\\" & sIPaddress & "\root\cimv2")
    Set cServicesThatDependOnIt = oWMI.ExecQuery("Associators of {Win32_Service.Name='" & sServiceName & "'} WHERE AssocClass=Win32_DependentService Role=Antecedent")
    
    For Each oItem In cServicesThatDependOnIt
        If oItem.State = "Running" Then 
    		If (oItem.StopService() <> 0) Then bFlag = False ': WScript.Echo "Problem stopping " & oItem.Name
        End If        
    Next
    
    WScript.Sleep 35000  
    
    Set cTargetService = oWMI.ExecQuery("SELECT * from Win32_Service WHERE Name='" & sServiceName & "'")
    For Each oItem In cTargetService
        If oItem.State = "Running" Then 
            If (oItem.StopService() <> 0) Then bFlag = False ': WScript.Echo "Problem stopping " & oItem.Name
        End If
    Next
    
    If (bFlag = True) And (Err.Number = 0) Then
        StopServiceAndAntecedents = True
    Else
        StopServiceAndAntecedents = False
    End If
    
    Set cServicesThatDependOnIt = Nothing
    Set cTargetService = Nothing
    Set oWMI = Nothing
End Function





'**********************************************************************************
'  Function: StartServiceAndAutostartDependents()
'   Purpose: Will start a service on a remote system, then start all other
'            services that depend on it IF those other services are currently
'            stopped AND their startup type is "Automatic".
'**********************************************************************************
Function StartServiceAndAutostartDependents(sIPaddress, sServiceName)
    On Error Resume Next
    Dim oWMI, cTargetService, cServicesThatDependOnIt, bFlag
    bFlag = True  'Assume function will work until error is detected.
    
    Set oWMI = GetObject("WinMgmts:{ImpersonationLevel=Impersonate}!\\" & sIPaddress & "\root\cimv2")
    
    Set cTargetService = oWMI.ExecQuery("SELECT * from Win32_Service WHERE Name='" & sServiceName & "'")
    For Each oItem In cTargetService
        If oItem.State = "Stopped" Then 
            If (oItem.StartService() <> 0) Then bFlag = False ': WScript.Echo "Problem starting " & oItem.Name
        End If
    Next
    
    WScript.Sleep 35000  
    
    Set cServicesThatDependOnIt = oWMI.ExecQuery("Associators of {Win32_Service.Name='" & sServiceName & "'} Where AssocClass=Win32_DependentService Role=Antecedent")
    For Each oItem In cServicesThatDependOnIt
        If oItem.State = "Stopped" And oItem.StartMode = "Auto" Then 
            If (oItem.StartService() <> 0) Then bFlag = False ': WScript.Echo "Problem starting " & oItem.Name
        End If
    Next
    
    If (bFlag = True) And (Err.Number = 0) Then
        StartServiceAndAutostartDependents = True
    Else
        StartServiceAndAutostartDependents = False
    End If

    Set cServicesThatDependOnIt = Nothing
    Set cTargetService = Nothing
    Set oWMI = Nothing
End Function



'**********************************************************************************
' Procedure: CatchAnyErrors()
'   Purpose: Handles errors in a hopefully useful way.
'**********************************************************************************
Sub CatchAnyErrors(msg)
	If Err.Number <> 0 Then
		sOutput = vbCrLf
		sOutput = sOutput &  "ERROR:             " & msg & vbCrLf 
		sOutput = sOutput &  "Error Number:      " & Err.Number & vbCrlf
		sOutput = sOutput &  "Error Description: " & Err.Description & vbCrLf
		sOutput = sOutput &  "Error Source:      " & Err.Source & vbCrLf 
		sOutput = sOutput &  "Script Name:       " & WScript.ScriptName & vbCrLf 
		sOutput = sOutput &  vbCrLf
		
        WScript.Echo sOutput
		'WScript.Quit Err.Number
	End If 
End Sub 


'END OF SCRIPT ********************************************************************
