'**********************************************************************************
' Script Name: Dump_Processes.vbs
'     Version: 1.0
'      Author: Jason Fossen, SANS Institute (www.sans.org)
'Last Updated: 3/18/03
'     Purpose: Scans a range of IP addresses, connects to each Windows 2000/XP/2003
'              system on which you have administrative access, and dumps a list of
'              all processes on each machine.  Filter/grep/search the output To
'              locate whatever service(s) you're trying to find, e.g., "inetinfo.exe".
'       Usage: Takes two arguments: beginning IP address and ending IP address.
'              Run in a CMD window.  Use CSCRIPT.EXE instead of WSCRIPT.EXE.
'       Notes: The functions/procedures of this script are taken from the 
'              SANS Institute's week-long training seminar on Windows Security, 
'              which includes a full day on scripting Windows (www.sans.org).
'       Notes: If you have WSH 5.6 or later, then alter the script below so that
'              only machines which respond to pings will be attempted.  Otherwise,
'              the script will attempt to connect to non-existent machines for
'              up to 40 seconds each (a tad slow for scanning...).  Get WSH 5.6
'              or later from http://msdn.microsoft.com/scripting/  (it's free).
'       Legal: Public Domain.  Modify and redistribute freely.  No rights reserved.
'              Script provided "as is" without implied warranty or guarantee.  Use
'              at your own risk and only on networks with prior written permission.
'**********************************************************************************

On Error Resume Next
Dim iStart, iEnd, sAddress, sIP, oWshShell
Set oWshShell = CreateObject("WScript.Shell")

If WScript.Arguments.Count <> 2 Then
    WScript.Echo vbCrLf & "Script requires two arguments: beginning-IP ending-IP."
    WScript.Echo "For example: cscript.exe dump_processes.vbs 10.4.1.1 10.4.3.254"
    WScript.Quit
Else
    iStart = IP2Number(WScript.Arguments.Item(0))
    iEnd   = IP2Number(WScript.Arguments.Item(1))
End If


For sAddress = iStart To iEnd
	sIP = Number2IP(sAddress)
	WScript.Echo "Attempting to connect to " & sIP & " ..." & vbCrLf
    ListProcesses(sIP)  'Comment this line out if the following is used instead.
    
	'''''Use the following line instead if you have WSH 5.6 or later.'''''
	'If IsPingable(sIP) Then ListProcesses(sIP)
Next



'**********************************************************************************
' Procedure: ListProcesses()
'   Purpose: Lists the processes on the target system.  Requires administrative
'            access on the Windows 2000/XP/2003 machine.
'**********************************************************************************
Sub ListProcesses(ByVal sIPaddress)
    On Error Resume Next
    Dim sOwner, sDomain 'These are variables which will hold the returns from GetOwner.  Strictly speaking, they are not needed here.
    
    Set oWMIobject = GetObject("WinMgmts://" & sIPaddress & "/root/cimv2:Win32_Process")
    Call CatchAnyErrors("Problem connecting to WMI object on " & sIPaddress)
    
    Set cProcesses = oWMIobject.Instances_  'Instances_ is a method of the WMI object which returns a collection.
    
    For Each oProcess In cProcesses
        oProcess.GetOwner sOwner, sDomain
    	WScript.Echo sIPaddress & " " & oProcess.Name & " PATH:(" & oProcess.ExecutablePath & ") PID:(" & oProcess.ProcessID & ") OWNER:(" & sDomain & "\" & sOwner & ")"
    Next
    
    Set cProcesses = Nothing    
    Set oWMIobject = Nothing
End Sub



'**********************************************************************************
' Function: IP2Number()
' Purpose: Convert a valid doted decimal IP address to
'          a 32-bit number.
'**********************************************************************************
Function IP2Number(ByVal sIP)
	aOctets = Split(sIP,".")
	IP2Number = (Int(aOctets(0)) * 16777216) + _
	            (Int(aOctets(1)) * 65536   ) + _ 
	            (Int(aOctets(2)) * 256     ) + _
	            (Int(aOctets(3))           )      
End Function



'**********************************************************************************
' Function: Number2IP()
' Purpose: Convert a 32-bit number to an IP address.
'**********************************************************************************
Function Number2IP(ByVal iNumber)
	Dim aOctets(4)
	aOctets(0) = Int(iNumber / 16777216)
    	iNumber = iNumber - (aOctets(0) * 16777216)
	aOctets(1) = Int(iNumber / 65536)
    	iNumber = iNumber - (aOctets(1) * 65536)   
	aOctets(2) = Int(iNumber / 256)
	aOctets(3) = iNumber - (aOctets(2) * 256)
	Number2IP = CStr(aOctets(0) & "." & aOctets(1) & "." & aOctets(2) & "." & aOctets(3))
End Function


'***********************************************************************************
'    Function: IsPingable()
'     Purpose: Captures the standard out (StdOut) of a launched process and uses
'              it to test whether a target IP address is pingable.
'       Notes: Requires WSH 5.6 or later!  
'       Notes: Modify the -n and -w switches in the Ping command to meet your needs.
'***********************************************************************************
Function IsPingable(sIPaddress)
    On Error Resume Next
	Dim sCommand, oExec, sLine
	sCommand = "ping.exe -n 2 -w 3000 " & sIPaddress  	
	IsPingable = False 
	
	If Not IsObject(oWshShell) Then Set oWshShell = CreateObject("WScript.Shell")
	Set oExec = oWshShell.Exec(sCommand)
		
	Do While Not oExec.StdOut.AtEndOfStream
		sLine = oExec.StdOut.ReadLine
	    If InStr(sLine,"Reply") <> 0 Then 
	    	IsPingable = True
	    	Exit Do
	    End If
	Loop
	
	Set oExec = Nothing
End Function



'**********************************************************************************
' Procedure: CatchAnyErrors()
'   Purpose: Handles errors in a hopefully useful way.
'**********************************************************************************
Sub CatchAnyErrors(msg)
	If Err.Number <> 0 Then
		sOutput = vbCrLf
		sOutput = sOutput &  "ERROR:             " & msg & vbCrLf 
		sOutput = sOutput &  "Error Number:      " & Err.Number & vbCrlf
		sOutput = sOutput &  "Error Description: " & Err.Description & vbCrLf
		sOutput = sOutput &  "Error Source:      " & Err.Source & vbCrLf 
		sOutput = sOutput &  "Script Name:       " & WScript.ScriptName & vbCrLf 
		sOutput = sOutput &  vbCrLf
		
        WScript.Echo sOutput
		'WScript.Quit Err.Number
	End If 
End Sub 


'END OF SCRIPT ********************************************************************
