'**************************************************************************
' Script Name: Append_To_Text_File.vbs
'     Version: 1.3
'      Author: Jason Fossen 
'Last Updated: 27.Jul.2004
'     Purpose: Function to append line(s) to the end of a text file.  
'              If the file does not exist, it will be created.  If the full
'              path to the file is not supplied, it is assumed to be in the
'              same folder as the script.  You need not append vbCr or vbCrLf
'              to the end of the data to be written, the script will append
'              a vbCr (carriage return) automatically.  Function returns true
'              if no errors, false otherwise.  
'       Notes: Because this function would repeatedly open and close the file,
'              this function is not appropriate for writing many lines to a single
'              file one line at a time.  Use the code chunk at the bottom for this,
'              or bundle the lines together before calling the function.  
'       Legal: Public Domain.  Modify and redistribute freely.  No rights reserved.
'**************************************************************************


Function AppendToTextFile(sLine, sFile)
    On Error Resume Next
    Const ForAppending =      8
    Const ForOverWriting =    2
    Const ForReading =        1
    Const OpenAsASCII =       0
    Const OpenAsUnicode =    -1
    Const OpenUsingDefault = -2
    
    If Not IsObject(oFileSystem) Then Set oFileSystem = WScript.CreateObject("Scripting.FileSystemObject")


    If InStr(sFile, "%") <> 0 Then
        If Not IsObject(oWshShell) Then Set oWshShell = WScript.CreateObject("WScript.Shell")
        sFile = oWshShell.ExpandEnvironmentStrings(sFile)
    End If 
    
    
    If InStr(sFile, "\") = 0 Then
        sCurrentFolder = WScript.ScriptFullName 
        sCurrentFolder = Left(sCurrentFolder, InstrRev(sCurrentFolder, "\"))
        sFile = sCurrentFolder & sFile
    End If    

    
    If Not oFileSystem.FileExists(sFile) Then 
        Set oTextStream = oFileSystem.CreateTextFile(sFile)
    Else
        Set oFile = oFileSystem.GetFile(sFile)
        Set oTextStream = oFile.OpenAsTextStream(ForAppending, OpenUsingDefault)     
    End If

    
    If oTextStream.Column = 1 Then
        oTextStream.WriteLine(sLine)  
    Else
        oTextStream.WriteBlankLines(1)
        oTextStream.WriteLine(sLine)
    End If

    oTextStream.Close
    
    Set oTextStream = Nothing   
    Set oFile = Nothing
    
    If Err.Number = 0 Then 
        AppendToTextFile = True  
    Else  
        AppendToTextFile = False
    End If
End Function



'END OF SCRIPT ***************************************




'The following demonstrates the function above.
sText = "Debugging scripts is like Zen while starving."
bFlag = AppendToTextFile(sText, "c:\test.txt")

For x = 1 to 100
    AppendToTextFile sText & x, "%SystemRoot%\test.txt"
Next



'If you will be writing many lines to a file, one line at a time, 
'then use something like this:
'
'   Set oFileSystem = WScript.CreateObject("Scripting.FileSystemObject")
'   Set oTextStream = oFileSystem.CreateTextFile("C:\test.txt")
'   For i = 0 to 1000
'       oTextStream.WriteLine("Debugging scripts is like Zen")
'   Next
'   oTextStream.Close
'
'Alternatively, bundle the lines together and write them all at
'once using the function above.  In any case, it is not efficient
'to call this function over-and-over again in short succession.  



