'***********************************************************************************
' Script Name: StopUniversalPnP.vbs
'     Version: 1.0
'      Author: Jason Fossen, The SANS Institute
'Last Updated: 12/27/01
'     Purpose: Stop and disable the Universal Plug and Play services underlying
'              the Windows XP vulnerability described in bulletin MS01-059 at
'              http://www.microsoft.com/technet/security/bulletin/MS01-059.asp
'       Usage: The script is independent of CSCRIPT.EXE or WSCRIPT.EXE, so it can
'              be simply double-clicked, run from the command-line, distributed
'              through Group Policy, made a logon/startup script, etc..  
'              Use "/?" switch for more command-line options.
'       Notes: This script is intended to run only on Windows XP.  Windows 98/ME can
'              optionally have the UPnP service installed, but it is not installed
'              by default (unlike XP).  The script only stops and disables the SSDP 
'              Discovery Service because the Universal Plug and Play Device Host 
'              depends on this service and therefore cannot start without it.  The
'              script will also write its output to the local Application log.
'    Keywords: PnP, Universal Plug and Play, Windows XP, XP, SANS, Fossen
'       Legal: Public Domain.  Modify and redistribute freely.  No rights reserved.
'              Script provided "AS IS" without implied warranty or guarantee.  If
'              you suspect that your system has been compromised by the UPnP
'              vulnerability already, then this script will NOT help you! 
'***********************************************************************************
On Error Resume Next


'***********************************************************************************
' Declare common objects and a few global variables.
'***********************************************************************************
Set oWshShell = WScript.CreateObject("WScript.Shell")
    Call CatchAnyErrorsAndQuit("Problem with Windows Script Host components (WSH).  Reinstall latest WSH.")
Set oWshShellNet = WScript.CreateObject("WScript.Network")
    Call CatchAnyErrorsAndQuit("Problem with Windows Script Host components (WSHnet).  Reinstall latest WSH.")

sReport     = vbCrLf & "Script Executed: StopUniversalPnP.vbs" & vbCrLf &_
              "For more information, see:" & vbCrLf &_ 
              "http://www.microsoft.com/technet/security/bulletin/MS01-059.asp" & vbCrLf & vbCrLf 
bEnable     = False
bSilent     = False
bShowUsage  = False



'***********************************************************************************
' Main() -- This section controls the rest of the script.
'***********************************************************************************
For Each sArg In WScript.Arguments  
    sArg = LCase(sArg)
    If (sArg = "?") OR (sArg = "-?") OR (sArg = "/?") OR (sArg = "h") OR (sArg = "-h") OR (sArg = "--help") OR (sArg = "/h") Then bShowUsage = True
    If (sArg = "silent") OR (sArg = "-silent") OR (sArg = "/silent") Then bSilent = True
    If (sArg = "enable") OR (sArg = "-enable") OR (sArg = "/enable") Then bEnable = True
Next

If bShowUsage Then Call ShowUsageAndQuit()    
If bEnable Then Call StartAndEnableSSDPSRV(sReport)
If NOT bEnable Then Call StopAndDisableSSDPSRV(sReport)
Call DisplayReport(sReport, bSilent)



'***********************************************************************************
' Procedures.
'***********************************************************************************
Sub StopAndDisableSSDPSRV(ByRef sReport)
    On Error Resume Next
            
    sComputerName = oWshShellNet.ComputerName    
    Set oPNPservice = GetObject("WinNT://" & sComputerName & "/SSDPSRV")
    If Err.Number = 0 Then
        oPNPservice.StartType = 4  'Disabled.
        oPNPservice.SetInfo
        If Err.Number = 0 Then 
            sReport = sReport & "SSDP Discovery Service set to disabled." & vbCrLf
        Else
            sReport = sReport & "ERROR in disabling SSDP Discovery Service!" & vbCrLf
            Err.Clear
        End If
        
        oPNPservice.Stop  'This will raise an error if already stopped, so we'll ignore any errors here.
       
        'Check that it really did stop...
        WScript.Sleep(10000) 'Give it 10 seconds to stop before testing its status.
        Set oWinNT = GetObject("WinNT://" & sComputerName)
        oWinNT.Filter = Array("Service")
    
        bIsReallyStopped = False
        For Each oService In oWinNT
            If (oService.Name = "SSDPSRV" and oService.Status = 1) Then bIsReallyStopped = True  'Status of 1 means "Stopped"
        Next
    
        If bIsReallyStopped Then sReport = sReport & "SSDP Discovery Service stopped." & vbCrLf  
        If Not bIsReallyStopped Then sReport = sReport & "ERROR when stopping SSDP Discovery Service!" & vbCrLf  
    
        Set oWinNT = Nothing
        Set oPNPservice = Nothing
    Else
        Set oPNPservice = Nothing  'habit...
        sReport = sReport & "ERROR in connecting to SSDP Discovery Service! Is this XP?" & vbCrLf
        Err.Clear
    End If
End Sub



Sub StartAndEnableSSDPSRV(ByRef sReport)
    On Error Resume Next
            
    sComputerName = oWshShellNet.ComputerName    
    Set oPNPservice = GetObject("WinNT://" & sComputerName & "/SSDPSRV")
    If Err.Number = 0 Then
        oPNPservice.StartType = 3  'Manual.
        oPNPservice.SetInfo
        If Err.Number = 0 Then 
            sReport = sReport & "SSDP Discovery Service enabled." & vbCrLf
        Else
            sReport = sReport & "ERROR in enabling SSDP Discovery Service!" & vbCrLf
            Err.Clear
        End If
        
        oPNPservice.Start  
       
        'Check that it really did stop...
        WScript.Sleep(10000) 'Give it 10 seconds to stop before testing its status.
        Set oWinNT = GetObject("WinNT://" & sComputerName)
        oWinNT.Filter = Array("Service")
    
        bIsReallyStopped = False
        For Each oService In oWinNT
            If (oService.Name = "SSDPSRV" and oService.Status = 4) Then bIsReallyStarted = True  'Statyus of 4 means "Started"
        Next
    
        If bIsReallyStarted Then sReport = sReport & "SSDP Discovery Service started." & vbCrLf  
        If Not bIsReallyStarted Then sReport = sReport & "ERROR when starting SSDP Discovery Service!" & vbCrLf  
    
        Set oWinNT = Nothing
        Set oPNPservice = Nothing
    Else
        Set oPNPservice = Nothing  'habit...
        sReport = sReport & "ERROR in connecting to SSDP Discovery Service! Is this XP?" & vbCrLf
        Err.Clear
    End If
End Sub



Sub ShowUsageAndQuit()
    sUsageInfo = vbCrLf
    sUsageInfo = sUsageInfo & "StopUniversalPnP.vbs (v.1.0) by Jason Fossen, The SANS Institute" & vbCrLf
    sUsageInfo = sUsageInfo & " " & vbCrLf
    sUsageInfo = sUsageInfo & "CSCRIPT.EXE StopUniversalPnP.vbs [/<option>] " & vbCrLf
    sUsageInfo = sUsageInfo & " " & vbCrLf
    sUsageInfo = sUsageInfo & "    /silent      = Suppresses output, but still writes to event log." & vbCrLf
    sUsageInfo = sUsageInfo & "    /enable      = Enables and starts SSDP Discovery Service." & vbCrLf
    sUsageInfo = sUsageInfo & "    /?           = This information." & vbCrLf
    sUsageInfo = sUsageInfo & " " & vbCrLf
    sUsageInfo = sUsageInfo & "   Notes: " & vbCrLf
    sUsageInfo = sUsageInfo & "    This script is intended to run only on Windows XP." & vbCrLf & vbCrLf
    sUsageInfo = sUsageInfo & "    With no command-line switches, i.e., the user simply double-clicks it," & vbCrLf
    sUsageInfo = sUsageInfo & "    the script stops and disables the SSDP Discovery Service, and is not silent." & vbCrLf & vbCrLf
    sUsageInfo = sUsageInfo & "    When using Group Policy to distribute the script, use the /silent switch." & vbCrLf & vbCrLf
    sUsageInfo = sUsageInfo & "    Output is also written to the local Application event log." & vbCrLf & vbCrLf
    sUsageInfo = sUsageInfo & "    You do not have to use this script to re-enable the SSDP Discovery Service; " & vbCrLf
    sUsageInfo = sUsageInfo & "    simply use the Services applet in Administrative Tools to set the startup " & vbCrLf
    sUsageInfo = sUsageInfo & "    type to Manual, and then start the service (or reboot)." & vbCrLf & vbCrLf
    WScript.Echo sUsageInfo
    WScript.Quit 0
End Sub



Sub DisplayReport(ByRef sReport, ByVal bSilent)
    oWshShell.LogEvent 2,sReport    'This writes the report to the Application event log on local machine.
    'oWshShell.LogEvent 2,sReport,"127.0.0.1"    'Edit the IP address here if you wish to write to a remote log.
    If NOT bSilent Then WScript.Echo sReport
End Sub



Sub CatchAnyErrorsAndQuit(ByVal sMsg)
	If Err.Number <> 0 Then
		sOutput = vbCrLf
		sOutput = sOutput &  "ERROR:             " & sMsg & vbCrLf 
		sOutput = sOutput &  "Error Number:      " & Err.Number & vbCrlf
		sOutput = sOutput &  "Error Description: " & Err.Description & vbCrLf
		sOutput = sOutput &  "Error Source:      " & Err.Source & vbCrLf 
		sOutput = sOutput &  "Script Name:       " & WScript.ScriptName & vbCrLf 
		sOutput = sOutput &  vbCrLf
		
        WScript.Echo sOutput
		WScript.Quit Err.Number
	End If 
End Sub 


'END OF SCRIPT *********************************************************************
